Word Embedding Bias
===================

.. automodule:: responsibly.we

Refer to the `Word Embedding demo <notebooks/demo-word-embedding-bias.html>`_
for a complete usage example.

For a technical discussion about the various bias metrics,
refer to the page :doc:`word-embedding-bias-metric-analysis`.

Check the `WEFE <https://wefe.readthedocs.io/en/latest/>`_
(The Word Embeddings Fairness Evaluation Framework) package
for additional word embeddings bias measures.


Bolukbasi Bias Measure and Debiasing
------------------------------------

.. automodule:: responsibly.we.bias
    :members:

WEAT
----

.. automodule:: responsibly.we.weat
    :members:

Utilities
---------

.. automodule:: responsibly.we.utils
    :members:

Word Embedding Benchmarks
-------------------------

.. automodule:: responsibly.we.benchmark
    :members:
